@@ -18,7 +18,7 @@ import urllib.parse as urlparse
 
 import html2text
 import youtube_dl
-import youtube_dl.utils
+from youtube_dl.utils import format_bytes
 
 from moodle_dl.state_recorder.file import File
 from moodle_dl.state_recorder.course import Course
@@ -99,12 +99,12 @@ class URLTarget(object):
         url_parts[4] = urlparse.urlencode(query)
         return urlparse.urlunparse(url_parts)
 
-    @staticmethod
-    def _create_dir(path: str):
+    def create_dir(self, path: str):
         # Creates the folders of a path if they do not exist.
         if not os.path.exists(path):
             try:
                 # raise condition
+                logging.debug('T%s - Create directory: "%s"', self.thread_id, path)
                 os.makedirs(path)
             except FileExistsError:
                 pass
@@ -133,6 +133,7 @@ class URLTarget(object):
 
             new_path = str(Path(destination) / new_filename)
 
+        logging.debug('T%s - Set up target file: "%s"', self.thread_id, new_path)
         Path(new_path).touch()
         self.fs_lock.release()
 
@@ -190,13 +191,24 @@ class URLTarget(object):
         def __init__(self, thread_id: int):
             self.thread_id = thread_id
 
+        def clean_msg(self, msg: str) -> str:
+            msg = msg.replace('\n', '')
+            msg = msg.replace('\r', '')
+            msg = msg.replace('\033[K', '')
+            msg = msg.replace('\033[0;31m', '')
+            msg = msg.replace('\033[0m', '')
+
+            return msg
+
         def debug(self, msg):
-            if msg.find('[download]') >= 0:
+            if msg.find('ETA') >= 0:
                 return
+            msg = self.clean_msg(msg)
             logging.debug('T%s - youtube-dl Debug: %s', self.thread_id, msg)
             pass
 
         def warning(self, msg):
+            msg = self.clean_msg(msg)
             if msg.find('Falling back') >= 0:
                 logging.debug('T%s - youtube-dl Warning: %s', self.thread_id, msg)
                 return
@@ -206,6 +218,7 @@ class URLTarget(object):
             logging.warning('T%s - youtube-dl Warning: %s', self.thread_id, msg)
 
         def error(self, msg):
+            msg = self.clean_msg(msg)
             if msg.find('Unsupported URL') >= 0:
                 logging.debug('T%s - youtube-dl Error: %s', self.thread_id, msg)
                 return
@@ -264,6 +277,7 @@ class URLTarget(object):
         destination = os.path.dirname(tmp_file)
         content_filename = os.path.basename(tmp_file)
 
+        logging.debug('T%s - Renaming "%s" to "%s"', self.thread_id, content_filename, self.filename)
         for filename in os.listdir(destination):
             if filename.startswith(content_filename + '.'):
                 one_tmp_file = os.path.join(destination, filename)
@@ -316,6 +330,8 @@ class URLTarget(object):
         """
 
         urlToDownload = self.file.content_fileurl
+        logging.debug('T%s - Try to download linked file %s.', self.thread_id, urlToDownload)
+
         if add_token:
             urlToDownload = self._add_token_to_url(self.file.content_fileurl)
 
@@ -376,6 +392,7 @@ class URLTarget(object):
                                     self.file.saved_to,
                                     e,
                                 )
+                                self.log_exception_extras(e)
                         self.move_tmp_file(tmp_file)
                         self.success = True
                         return True
@@ -463,6 +480,7 @@ class URLTarget(object):
         both cases are covered here.
         """
 
+        logging.debug('T%s - Creating a shortcut', self.thread_id)
         with open(self.file.saved_to, 'w+', encoding='utf-8') as shortcut:
             if os.name == 'nt':
                 shortcut.write('[InternetShortcut]' + os.linesep)
@@ -523,15 +541,14 @@ class URLTarget(object):
         description.close()
 
         if to_save == '':
-            try:
-                os.remove(self.file.saved_to)
+            logging.debug('T%s - Remove target file because description file would be empty.', self.thread_id)
+            os.remove(self.file.saved_to)
 
-                self.file.time_stamp = int(time.time())
+            self.file.time_stamp = int(time.time())
 
-                self.success = True
-            except Exception as e:
-                self.error = traceback.format_exc() + '\nError:' + str(e)
+            self.success = True
         else:
+            logging.debug('T%s - Creating a description file', self.thread_id)
             self.file.time_stamp = int(time.time())
 
             self.success = True
@@ -549,6 +566,7 @@ class URLTarget(object):
         if not os.path.exists(old_path):
             return False
 
+        logging.debug('T%s - Moving old file "%s" to new target location.', self.thread_id, old_path)
         try:
             shutil.move(old_path, self.file.saved_to)
             self.file.time_stamp = int(time.time())
@@ -568,10 +586,12 @@ class URLTarget(object):
                 return True
             except Exception as e:
                 logging.warning('T%s - Moving the old file %s failed!  Error: %s', self.thread_id, old_path, e)
+                self.log_exception_extras(e)
 
             self.fs_lock.release()
         except Exception:
             logging.warning('T%s - Moving the old file %s failed unexpectedly!  Error: %s', self.thread_id, old_path, e)
+            self.log_exception_extras(e)
 
         return False
 
@@ -589,7 +609,7 @@ class URLTarget(object):
 
         try:
             logging.debug('T%s - Starting downloading of: %s', self.thread_id, self)
-            self._create_dir(self.destination)
+            self.create_dir(self.destination)
 
             # if file was modified try rename the old file,
             # before create new one
@@ -635,6 +655,8 @@ class URLTarget(object):
                 return self.success
 
             url_to_download = self.file.content_fileurl
+            logging.debug('T%s - Downloading %s.', self.thread_id, url_to_download)
+
             if add_token:
                 url_to_download = self._add_token_to_url(self.file.content_fileurl)
 
@@ -659,6 +681,7 @@ class URLTarget(object):
                 pass
 
             logging.error('T%s - Error while trying to download file: %s', self.thread_id, self)
+            self.log_exception_extras(e)
 
             if self.downloaded == 0 and filesize == 0:
                 try:
@@ -672,6 +695,7 @@ class URLTarget(object):
                         self.file.saved_to,
                         e,
                     )
+                    self.log_exception_extras(e)
             else:
                 # Subtract the already downloaded content in case of an error.
                 self.thread_report[self.thread_id]['total'] -= self.downloaded
@@ -679,8 +703,7 @@ class URLTarget(object):
 
         return self.success
 
-    @staticmethod
-    def urlretrieve(url: str, filename: str, context: ssl.SSLContext, reporthook=None, cookies_path=None):
+    def urlretrieve(self, url: str, filename: str, context: ssl.SSLContext, reporthook=None, cookies_path=None):
         """
         original source:
         https://github.com/python/cpython/blob/
@@ -689,6 +712,7 @@ class URLTarget(object):
         Because urlopen also supports context,
         I decided to adapt the download function.
         """
+        start = time.time()
         url_parsed = urlparse.urlparse(url)
 
         request = urllib.request.Request(url=url, headers=RequestHelper.stdHeader)
@@ -739,8 +763,36 @@ class URLTarget(object):
         if size >= 0 and read < size:
             raise ContentTooShortError('retrieval incomplete: got only %i out of %i bytes' % (read, size), result)
 
+        end = time.time()
+        logging.debug(
+            'T%s - Download of %s finished in %s', self.thread_id, format_bytes(read), self.format_seconds(end - start)
+        )
+
         return result
 
+    @staticmethod
+    def format_seconds(seconds):
+        (mins, secs) = divmod(seconds, 60)
+        (hours, mins) = divmod(mins, 60)
+        if hours > 99:
+            return '--:--:--'
+        if hours == 0:
+            return '%02d:%02d' % (mins, secs)
+        else:
+            return '%02d:%02d:%02d' % (hours, mins, secs)
+
+    def log_exception_extras(self, exc):
+        """Log the extras of an exception object
+
+        Args:
+            exc (Exception): Exception that has occurred
+        """
+        if hasattr(exc, 'winerror'):
+            logging.debug("Exception winerror: %s", exc.winerror)
+
+        if hasattr(exc, 'winerror'):
+            logging.debug("Exception errno: %s", exc.errno)
+
     def __str__(self):
         # URLTarget to string
         return 'URLTarget (%(file)s, %(course)s, %(success)s, Error: %(error)s)' % {
